/**
 * Интерфейс для реализации двух функций, в каждом обекте который необходимо отслеживать на изменение.
 */
export interface EngineObject {
    /** * Преобразование обекта в строку.*/
    toString(): string;
    /**
     * Возвращает значение хэш-кода для объекта.
     * Общий контракт hashCode:
     * Всякий раз, когда он вызывается для одного и того же объекта более одного раза во время выполнения приложения,
     * метод hashCode должен постоянно возвращать одно и то же целое число, при условии, что никакая информация,
     * используемая в сравнениях на равенство для объекта, не изменяется.
     * Это целое число не обязательно должно оставаться постоянным от одного выполнения приложения к другому выполнению того же приложения.
     * Если два объекта равны в соответствии с методом equals(Object), то вызов метода hashCode для каждого из двух объектов должен давать одинаковый целочисленный результат.
     * @returns значение хеш-кода для этого объекта.
     */
    hashCode(): number;
    /** Метод глубокого сравнения */
    equals(object: EngineObject): boolean;
}
