import { Bits } from "../utils/Bits";
import { ComponentClass } from "./Component";
export declare class ComponentType {
    private static assignedComponentTypes;
    private static typeIndex;
    private readonly index;
    /**
     * Уникально идентифицирует подкласс {@link Component}. Он присваивает им индекс, который используется внутри для быстрого сравнения и
     * поиск. См. {@link Family} и {@link Entity}. ComponentType — это класс, защищенный пакетом. Вы не можете создать экземпляр
     * Тип компонента. Доступ к ним возможен только через {@link #getIndexFor(Class<? extends Component>)}. Каждый класс компонентов всегда
     * вернуть тот же экземпляр ComponentType.
     * @author Stefan Bachmann
     */
    private constructor();
    /** @return Уникальный индекс этого ComponentType */
    getIndex(): number;
    /**
     * @param componentType Класс {@link Component}
     * @return Тип компонента, соответствующий классу компонента
     */
    static getFor(componentType: ComponentClass): ComponentType;
    /**
     * Быстрый вспомогательный метод. То же самое можно сделать с помощью {@link ComponentType.getFor(Component)}.
     * @param componentType Класс {@link Component}
     * @return Индекс для указанного класса {@link Component}.
     */
    static getIndexFor(componentType: ComponentClass): number;
    /**
     * @param componentTypes список {@link Component} классов
     * @return Биты, представляющие набор компонентов для быстрого сравнения и сопоставления. Видеть
     *         {@link Family#getFor(Bits, Bits, Bits)}.
     */
    static getBitsFor(...componentTypes: ComponentClass[]): Bits;
    hashCode(): number;
    equals(obj: object): boolean;
}
