import { EngineObject } from "../@interfaces/EngineObject";
import { Signal } from "../signals/Signal";
import { Bits } from "../utils/Bits";
import { ImmutableArray } from "../utils/ImmutableArray";
import { Component, ComponentClass } from "./Component";
import { ComponentType } from "./ComponentType";
export declare class Entity implements EngineObject {
    id: number;
    key: string;
    parentKey?: string;
    /** Отправит событие при добавлении компонента. */
    readonly componentAdded: Signal<Entity>;
    /** Будет отправлять событие при удалении компонента. */
    readonly componentRemoved: Signal<Entity>;
    private components;
    private immutableComponentsArray;
    private componentBits;
    private familyBits;
    flags: number;
    scheduledForRemoval: boolean;
    removing: boolean;
    componentsArray: Component[];
    constructor();
    /**
       * Добавляет {@link Component} в этот объект. Если {@link Component} того же
       * типа уже существует, он будет заменен.
       * @return Вернет {@link Entity} для простой цепочки
       */
    add(component: Component): this;
    /**
         * Добавляет {@link Component} в этот объект. Если {@link Component} того же
         * типа уже существует, он будет заменен.
         *
         * @return Компонент для прямого управления компонентом (например,
         *         Объединенный компонент)
         */
    addAndReturn<T extends Component>(component: T): T;
    /**
         * Удаляет {@link Component} указанного типа. Поскольку существует только один
         * компонент одного типа, нам не нужена
         * ссылка на экземпляр.
         *
         * @return Удаленный {@link Component} или null, если объект не содержит
         *         такой компонент.
         */
    remove<T extends Component>(componentClass: ComponentClass): Component | null;
    /**
     * Удаляет все комопненты.
     */
    removeAll(): void;
    /**
     * Получить компонент
     * @param componentType класс компонента
     * @returns Объект {@link Component} для указанного класса, null, если
       *         сущность не имеет компонентов для этого класса
     */
    getComponent<T extends Component>(component: ComponentType): T | null;
    getComponent<T extends Component>(component: ComponentClass): T | null;
    /**
     * @returns неизменяемая коллекция со всеми компонентами {@link Component}
     */
    getComponents(): ImmutableArray<Component>;
    /**
     * @param componentType Класс комопнента
     * @returns Имеет ли сущность {@link Component} для указанного класса.
     */
    hasComponent(componentType: ComponentType): boolean;
    /**
       * @return Биты компонентов этого объекта, описывающие все {@link Component},
       *         которые он содержит.
       */
    getComponentBits(): Bits;
    /**
       * @return Биты {@link Family} этой сущности, описывающие все
       *         {@link EntitySystem}, которыми она в настоящее время обрабатывается.
       */
    getFamilyBits(): Bits;
    private addInternal;
    removeInternal(componentClass: ComponentClass): Component | null;
    notifyComponentAdded(): void;
    notifyComponentRemoved(): void;
    isRemoving(): boolean;
    isScheduledForRemoval(): boolean;
    toString(): string;
    hashCode(): number;
    equals(object: EngineObject): boolean;
}
