import { Engine } from "../core/Engine";
import { Entity } from "../core/Entity";
import { EntitySystem } from "../core/EntitySystem";
import { Family } from "../core/Family";
import { ImmutableArray } from "../utils/ImmutableArray";
export declare abstract class IteratingSystem extends EntitySystem {
    private readonly family;
    private entities;
    constructor(sysClass: any, family: Family, priority?: number);
    addedToEngine(engine: Engine): void;
    removedFromEngine(engine: Engine): void;
    /**
     * @returns семейство, которое использовалось для создания системы.
     */
    getFamily(): Family;
    /**
     * @return набор сущностей, обрабатываемых системой
     */
    getEntities(): ImmutableArray<Entity> | null;
    update(deltaTime: number): Promise<void>;
    /**
     * Этот метод вызывается для каждой сущности при каждом вызове обновления
     * EntitySystem. Переопределите это, чтобы реализовать
     * специальная обработка.
     *
     * @param entity    Текущая обрабатываемая сущность
     * @param deltaTime Разница во времени между последним и текущим кадром
     */
    protected abstract processEntity(entity: Entity, deltaTime: number): Promise<void>;
    /**
     * Этот метод вызывается один раз при каждом вызове обновления EntitySystem до
     * начала обработки объекта. Переопределите этот метод, чтобы
     * реализовать ваши конкретные условия запуска.
     */
    startProcessing(): Promise<void>;
    /**
     * Этот метод вызывается один раз при каждом вызове обновления EntitySystem
     * после завершения обработки сущности. Переопределите этот метод, чтобы
     * реализуйте свои конкретные конечные условия.
     */
    endProcessing(): Promise<void>;
}
