import { EngineObject } from "../@interfaces/EngineObject";
export declare class Bits implements EngineObject {
    bits: number[];
    /** Создает набор битов, начальный размер которого nbits
     * @param nbits начальный размер набора битов */
    constructor(nbits?: number);
    /** Создает битовый набор из другого битового набора
     * @param bitsToCpy битовый набор для copy */
    static copy(bitsToCpy: Bits): Bits;
    /**
     * @param index индекс бита
     * @return установлен ли бит
     * @throws если индекс < 0 */
    get(index: number): boolean;
    /** Возвращает бит по заданному индексу и очищает его за один раз.
     * @param index индекс бита
     * @return, если бит был установлен до вызова
     * @throws если индекс < 0 */
    getAndClear(index: number): boolean;
    /** Возвращает бит по заданному индексу и устанавливает его за один раз.
     * @param index индекс бита
     * @return, если бит был установлен до вызова
     * @throws  если индекс < 0 */
    getAndSet(index: number): boolean;
    /**
     * @param index индекс устанавливаемого бита
     * @throws если индекс < 0 */
    set(index: number): void;
    /** @param index индекс переворачиваемого бита */
    flip(index: number): void;
    clear(index?: number): void;
    /** @return число битов, хранящихся в настоящее время, <b>не</b> самый высокий установленный бит! */
    numBits(): number;
    /**
     * Возвращает «логический размер» этого набора битов: индекс старшего установленного бита в наборе битов плюс один. Возвращает ноль, если
     * набор битов не содержит установленных битов.
     *
     * @вернуть логический размер этого набора битов */
    length(): number;
    /** @return true, если этот набор битов содержит хотя бы один бит, установленный в true */
    notEmpty(): boolean;
    /** @return true, если этот набор битов не содержит битов, для которых установлено значение true */
    isEmpty(): boolean;
    /** Возвращает индекс первого бита, для которого установлено значение true, который встречается в указанном начальном индексе или после него. Если нет такого бита
     * существует, то возвращается -1. */
    nextSetBit(fromIndex: number): number;
    /** Возвращает индекс первого бита, для которого установлено значение false, который встречается в указанном начальном индексе или после него. */
    nextClearBit(fromIndex: number): number;
    /** Выполняет логическое <b>И</b> этого целевого набора битов с установленным битом аргумента. Этот набор битов изменен так, что каждый бит
     * в нем имеет значение true тогда и только тогда, когда он изначально имел значение true и соответствующий бит в битовом наборе
     * Аргумент также имел значение true.
     * @param other
     */
    and(other: Bits): void;
    /** Очищает все биты в этом наборе битов, соответствующие биты которых установлены в указанном наборе битов.
     *
     * @param другой бит установлен */
    andNot(other: Bits): void;
    /** Выполняет логическое <b>ИЛИ</b> этого битового набора с аргументом битового набора. Этот битовый набор изменен так, что бит в нем имеет
     * значение true тогда и только тогда, когда оно либо уже имело значение true, либо соответствующий бит в аргументе набора битов имеет
     * значение верно.
     * @param другой бит установлен */
    or(other: Bits): void;
    /** Выполняет логическое <b>исключающее ИЛИ</b> этого битового набора с аргументом битового набора. Этот битовый набор изменен так, что бит в нем имеет
     * значение true тогда и только тогда, когда выполняется одно из следующих утверждений:
     * <ул>
     * <li>Бит изначально имеет значение true, а соответствующий бит в аргументе имеет значение false.</li>
     * <li>Бит изначально имеет значение false, а соответствующий бит в аргументе имеет значение true.</li>
     * </ul>
     * @параметр другой */
    xor(other: Bits): void;
    /** Возвращает истину, если в указанном наборе битов есть какие-либо биты, установленные в значение «истина», которые также установлены в значение «истина» в этом наборе битов.
     *
     * @param другой бит установлен
     * @return логическое значение, указывающее, пересекается ли этот набор битов с указанным набором битов */
    intersects(other: Bits): boolean;
    /** Возвращает значение true, если этот набор битов является надмножеством указанного набора, т. е. все биты, установленные в значение true, также установлены в значение
     * true в указанном BitSet.
     *
     * @return логическое значение, указывающее, является ли этот набор битов надмножеством указанного набора */
    containsAll(other: Bits): boolean;
    setBits(bits: number[]): Bits;
    private checkCapacity;
    toString(): string;
    hashCode(): number;
    equals(obj: EngineObject): boolean;
}
